#[repr(u8)]pub enum Tag {
Unnecessary = 0,
Deprecated = 1,
}Expand description
Diagnostic tag.
Represents additional tags of a Diagnostic, which is defined by and
in line with the tags as defined by the Language Server Protocol.
Variants