debug

Macro debug 

macro_rules! debug {
    (&mut $sink:expr, $($arg:tt)+) => { ... };
    ($($arg:tt)*) => { ... };
}
Creates a diagnostic with debug severity.

This macro creates a diagnostic message with Severity::Debug, using either a static string or a format string as an argument.

The diagnostic will include file, line and column information.

Examples

use zrx_diagnostic::debug;

// Create diagnostic with static string
let diagnostic = debug!("Static");

// Create diagnostic with format string
let diagnostic = debug!("Format: {}", true);